<?php
## BIBIS の設定ファイル。
## 「#define」で始まる行は現バージョンのデフォルト値。
## 「# define」で始まる行は記述例など。

####### セキュリティー設定

## パスワードのハッシュ化のソルト。必ずランダムな値に変更すること。
define('PASSWORD_SOLT', 'UNSAFE_DEFAULT_SOLT');

## ハッシュ関数の適用回数。変更不要だが省略不可。
define('PASSWORD_ITER', 1000);

## php.ini の open_basedir を上書きする。
## 参考: https://www.php.net/manual/ja/ini.core.php#ini.open-basedir
# define('OPEN_BASEDIR', __DIR__ . '/data/:/tmp/');

####### データの保存先

## データ保存先のフォルダー。php-fpm から書き込み可能であること。
#define('DATA_ROOT', __DIR__  . '/data/');

## ファイルごとの保存先。
#define('USERS_TSV', DATA_ROOT . 'users.tsv');
#define('LIMIT_TSV', DATA_ROOT . 'repeating-limit.tsv');
#define('PROFILE_DIR', DATA_ROOT . 'profile/');
#define('POST_DIR', DATA_ROOT . 'post/');
#define('POST_LOCK_TEXT', DATA_ROOT . 'post-lock.txt');
#define('ATTACHMENT_DIR', DATA_ROOT . 'attachment/');

####### サイト設定

## 画面上に表示するサイト名。
define('SITENAME', 'BIBIS');

## タイムライン・プロフィールの1ページあたりの投稿数
#define('POSTS_PER_PAGE', 20);

## 掲示板内のURLのルート。
## a 要素の href などの起点となる。
## 例1: http://example.com/ で公開したい場合「/」を指定する。
## 例2: http://example.com/bbs/ で公開したい場合「/bbs/」を指定する。
define('SITEBASE', '/');
# define('SITEBASE', '/bbs/');

## タイムゾーン(畫面上の表示にのみ使用)
#define('TIMEZONE', 'UTC');
# define('TIMEZONE', 'Asia/Tokyo');

## 投稿の日付のみを表示して時刻を隠す。
# define('HIDE_TIME', true);

## テーマを上書きする。
## public/theme フォルダ内に CSS を配置し、そのファイル名を指定する。フォルダ名は不要。
# define('THEME', '076.css'); # 「076萌SNS」風テーマ

####### 機能の有効化

## 投稿を有効にする。
define('ENABLE_POST', true);

## 投稿時間のごまかしを有効にする。
# define('ENABLE_SPOOF_TIME', true);

# define('ENABLE_FAKE_ERROR', true);

## 投稿に COOKIE を必須にする。
# define('REQUIRE_COOKIE', true);

## ゲスト(未ログインユーザーの投稿)を有効にする。
define('ENABLE_GUEST', true);

## ログインを有効にする。
define('ENABLE_LOGIN', true);

## 新規登録を有効にする。
define('ENABLE_REGISTER', true);

## 添付ファイル機能を有効にする。無効にすると過去のファイルも閲覧不可。
# define('ENABLE_ATTACHMENT', true);

# 画像アップロードを有効にする。無効にしても過去のファイルは閲覧可能。
# define('ENABLE_IMAGE', true);

# 画像の縮小版を有効にする。
#define('ENABLE_THUMBNAIL', true);

####### レート制限

## スレッドの長さの上限。これを越えると返信できない。
define('THREAD_SIZE', 100);

## サイト全体の投稿数の上限。これを越えると誰も投稿できない。
define('POST_LIMIT', 5000);

## サイト全体の1日の投稿数の上限。これを越えると翌日まで投稿できない。
define('POST_LIMIT_PER_DAY', 50);

## ユーザー数の上限。これを越えると新規登録ができない。
define('USER_LIMIT', 50);

####### フック関数

## HTMLの出力の直前に呼ばれる関数。
function bibis_http_header() {
	// 同一ドメインの「画像」「CSS」を許可。他は禁止。
	// (支障があれば修正、又はコメントアウトする。)
	header("Content-Security-Policy: default-src 'none'; img-src 'self'; style-src 'self'");
}

####### デバッグ用

## コメントアウトを解除するとPHPのErrorやWarningが表示される。
# define('BIBIS_DEBUG', true);
