<?php
require_once(__DIR__ . '/../../src/require.php');

# TODO: thumbnail cache

if (!ENABLE_ATTACHMENT) { return on_error(404, ['Not Found.']); }

$size = $_GET['size'] ?? '';
$id = $_GET['id'] ?? '';
if ($id == '' || !preg_match('/^[a-z0-9]{32}$/', $id)) { return on_error(400, ['URLが不正。']); }

$filepath = ATTACHMENT_DIR . $id . '.gz';
if (!file_exists($filepath)) { return on_error(404, ['Not Found.']); }

ob_start();
readgzfile($filepath);
$buffer = ob_get_clean();
$type = get_image_type($buffer);
if (!isset($type)) { return on_error(500, ['ファイルが不正。']); }

$thumb_size = 256;
$sizepx = '';
$is_thumbnail = ($size === 'min' && ENABLE_THUMBNAIL);
if ($is_thumbnail) {
	$sizepx = "$thumb_size";
}

$php_time = filemtime(__FILE__);
$attachment_time = filemtime($filepath);
$etag = '"' . $php_time . '.' . $attachment_time . $sizepx. '"';

header('Cache-Control: max-age=86400');
header("ETag: {$etag}");

if (isset($_SERVER['HTTP_IF_NONE_MATCH'])) {
	if ($_SERVER['HTTP_IF_NONE_MATCH'] === $etag) {
		header('HTTP/1.1 304 Not Modified', true, 304);
		exit();
	}
}

// サムネイル
if ($is_thumbnail) {
	$thumb_width = $thumb_size;
	$thumb_height = $thumb_size;

	$src = imagecreatefromstring($buffer);
	$src_width = imagesx($src);
	$src_height = imagesy($src);

	$thumb_width = min($thumb_width, $src_width);
	$thumb_height = min($thumb_height, $src_height);

	if ($src_width >= $src_height) {
		$thumb_height = floor($src_height * ($thumb_width / $src_width));
	}
	else {
		$thumb_width = floor($src_width * ($thumb_height / $src_height));
	}

	$thumb = imagecreatetruecolor($thumb_width, $thumb_height);

	imagecopyresampled(
		$thumb,
		$src,
		0,
		0,
		0,
		0,
		$thumb_width,
		$thumb_height,
		$src_width,
		$src_height
	);

	header('Content-Type: image/jpeg');
	imagejpeg($thumb);
	imagedestroy($src);
	imagedestroy($thumb);
	return;
}

// 通常
header("Content-Type: {$type}");
echo $buffer;
